# -*- coding: utf-8 -*-
# Generated by Django 1.9.9 on 2016-09-26 21:52
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('fobi', '0006_auto_20160911_1549'),
    ]

    operations = [
        migrations.CreateModel(
            name='FormWizardFormEntry',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('position', models.PositiveIntegerField(blank=True, null=True, verbose_name='Position')),
            ],
            options={
                'ordering': ['position'],
                'abstract': False,
                'verbose_name': 'Form wizard form entry',
                'verbose_name_plural': 'Form wizard form entries',
            },
        ),
        migrations.RemoveField(
            model_name='formentry',
            name='form_wizard_entry',
        ),
        migrations.RemoveField(
            model_name='formentry',
            name='position',
        ),
        migrations.AddField(
            model_name='formwizardentry',
            name='created',
            field=models.DateTimeField(auto_now_add=True, null=True, verbose_name='Created'),
        ),
        migrations.AddField(
            model_name='formwizardentry',
            name='success_page_message',
            field=models.TextField(blank=True, help_text='Custom message text to display after valid form is submitted', null=True, verbose_name='Success page body'),
        ),
        migrations.AddField(
            model_name='formwizardentry',
            name='success_page_title',
            field=models.CharField(blank=True, help_text='Custom message title to display after valid form is submitted', max_length=255, null=True, verbose_name='Success page title'),
        ),
        migrations.AddField(
            model_name='formwizardentry',
            name='updated',
            field=models.DateTimeField(auto_now=True, null=True, verbose_name='Updated'),
        ),
        migrations.AddField(
            model_name='formwizardformentry',
            name='form_entry',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='fobi.FormEntry', verbose_name='Form entry'),
        ),
        migrations.AddField(
            model_name='formwizardformentry',
            name='form_wizard_entry',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='fobi.FormWizardEntry', verbose_name='Form wizard entry'),
        ),
        migrations.AlterUniqueTogether(
            name='formwizardformentry',
            unique_together=set([('form_wizard_entry', 'form_entry')]),
        ),
    ]
