{% extends fobi_theme.form_edit_ajax %}

{% load i18n %}

{% block form_page_title %}
{% trans "Create form wizard" %}
{% endblock form_page_title %}

{% block form_primary_button_text %}{% trans "Add" %}{% endblock %}
