/*
   .datepicker {
   .prev, .next {font-style:normal;}
   .prev:after {content:"Â«";}
   .next:after {content:"Â»";}
   }
 */
/*!
 * Datepicker for Foundation - less stylesheet, just version customized to foundation
 *
 * Copyright 2013 Peter Beno, najlepsiwebdesigner@gmail.com, @benopeter
 * project website http://foundation-datepicker.peterbeno.com
 *
 * Original project https://github.com/eternicode/bootstrap-datepicker
 * 		Original author 2012 Stefan Petre
 * 		Improvements by Andrew Rowls
 * 		Licensed under the Apache License v2.0
 * 		http://www.apache.org/licenses/LICENSE-2.0
 */
.datetimepicker.dropdown-menu {
    position: absolute;
    top: 100%;
    left: 0;
    z-index: 1000;
    float: left;
    display: none;
    min-width: 160px;
    list-style: none;
    background-color: #fff;
    border: 1px solid #ccc;
    border: 1px solid rgba(0, 0, 0, .2);
    -webkit-border-radius: 5px;
    -moz-border-radius: 5px;
    border-radius: 5px;
    -webkit-box-shadow: 0 5px 10px rgba(0, 0, 0, .2);
    -moz-box-shadow: 0 5px 10px rgba(0, 0, 0, .2);
    box-shadow: 0 5px 10px rgba(0, 0, 0, .2);
    -webkit-background-clip: padding-box;
    -moz-background-clip: padding;
    background-clip: padding-box;
    *border-right-width: 2px;
    *border-bottom-width: 2px;
    color: #333;
    font-family: "Open Sans", sans-serif;
    font-size: 13px;
    line-height: 18px;
}
.datetimepicker.dropdown-menu th, .datetimepicker.dropdown-menu td {
    padding: 4px 5px;
}
.datetimepicker {
    display: none;
    position: absolute;
    padding: 4px;
    margin-top: 1px;
    direction: ltr;
}
.datetimepicker-inline {
    width: 220px;
    display: none;
}
.datetimepicker-rtl {
    direction: rtl;
}
.datetimepicker-rtl table tr td span {
    float: right;
}
.datetimepicker-dropdown {
    top: 0;
    left: 0;
}
.datetimepicker-dropdown:before {
    content: '';
    display: inline-block;
    border-left: 7px solid transparent;
    border-right: 7px solid transparent;
    border-bottom: 7px solid #ccc;
    border-bottom-color: rgba(0, 0, 0, .2);
    position: absolute;
    top: -7px;
    left: 6px;
}
.datetimepicker-dropdown:after {
    content: '';
    display: inline-block;
    border-left: 6px solid transparent;
    border-right: 6px solid transparent;
    border-bottom: 6px solid #fff;
    position: absolute;
    top: -6px;
    left: 7px;
}
.datetimepicker>div {
    display: none;
}
.datetimepicker.days div.datepicker-days {
    display: block;
}
.datetimepicker.months div.datepicker-months {
    display: block;
}
.datetimepicker.years div.datepicker-years {
    display: block;
}
.datetimepicker table {
    border: 0;
    margin: 0;
}
.datetimepicker td, .datetimepicker th {
    text-align: center;
    width: 20px;
    height: 20px;
    border: 0;
    font-size: 12px;
    padding: 4px 8px;
    background: #fff;
    cursor: pointer;
}
.datetimepicker td.active.day, .datetimepicker th.active.day {
    background: #2ba6cb;
}
.datetimepicker td.active.year, .datetimepicker th.active.year {
    background: #2ba6cb;
}
.datetimepicker td span.active, .datetimepicker th span.active {
    background: #2ba6cb;
}
.table-striped .datetimepicker table tr td, .table-striped .datetimepicker table tr th {
    background-color: transparent;
}
.datetimepicker table tr td.day.old{
    color: #808080;
}
.datetimepicker table tr td.day.new{
    color: #808080;
}
.datetimepicker table tr td span {
    display: block;
    width: 23%;
    height: 54px;
    line-height: 54px;
    float: left;
    margin: 1%;
    cursor: pointer;
}
.datetimepicker th.switch {
    width: 145px;
}
.datetimepicker thead tr:first-child th, .datetimepicker tfoot tr:first-child th {
    cursor: pointer;
}
.datetimepicker .cw {
    font-size: 10px;
    width: 12px;
    padding: 0 2px 0 5px;
    vertical-align: middle;
}
.datetimepicker thead tr:first-child th.cw {
    cursor: default;
    background-color: transparent;
}
.datetimepicker-dropdown::before, .datetimepicker-dropdown::after {
    display: none;
}
.datetimepicker-close {
    position: absolute;
    top: -30px;
    right: 0;
    width: 15px;
    height: 30px;
    padding: 0;
    display: none;
}

/* This beautiful CSS-File has been crafted with LESS (lesscss.org) and compiled by simpLESS (wearekiss.com/simpless) */
