from __future__ import print_function

import unittest

from .tests.test_browser_build_dynamic_forms import *
from .tests.test_core import *
from .tests.test_dynamic_forms import *
from .tests.test_sortable_dict import *

__title__ = 'fobi.test'
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = '2014-2016 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'


if __name__ == '__main__':
    unittest.main()
