{% extends fobi_theme.base_edit_template %}

{% load i18n %}

{% block page-title %}{% blocktrans with form_wizard_handler_plugin.name as plugin_name %}Add "{{ plugin_name }}" handler to the form wizard{% endblocktrans %}{% endblock page-title %}

{% block navbar-menu-content %}
{% endblock navbar-menu-content %}

{% block content %}
    {% include fobi_theme.add_form_wizard_handler_entry_ajax_template %}
{% endblock content %}

{% block sidebar-content %}
{% endblock sidebar-content %}