.slider .slider-selection {
    background: none;
    background-image: none;
}
.slider .slider-selection.tick-slider-selection {
    background: none;
    background-image: none;
}
.slider .slider-tick.in-selection {
    background-image: linear-gradient(to bottom, #f5f5f5 0, #c5c5c5 100%);
}